@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,13 +43,13 @@ void cancel_process_clicked(struct w *widgets)
 
     /* Set by status_update() */
     if( ! client_active )
-      return;
+        return;
 
-    /* Kill all rsync processes (This is not optimal) */
-    cmd = g_strdup_printf("killall -9 rsync");
+    /* Kill all rsync processes */
+    cmd = g_strdup_printf("killall -9 --user root rsync");
     if( ! run_command(cmd) )
     {
-	printf("Error: Can not kill the process.\n");
+        printf("Error: Can not kill the process.\n");
     }
     g_free(cmd);
 }
@@ -63,29 +63,29 @@ void backup_button_clicked(struct w *widgets)
 
     /* Set by status_update() */
     if( client_active )
-      return;
+        return;
 
     script_path = mk_backup_script_path(global_backup_name);
     if( script_path == NULL || strlen(script_path) < 1 )
     {
-	info = g_strdup_printf(_("The backup has no backup script.\nYou need to add a backup first.\n"));
-	show_info(info);
-	g_free(info);
+        info = g_strdup_printf(_("The backup has no backup script.\nYou need to add a backup first.\n"));
+        show_info(info);
+        g_free(info);
 
-	if( script_path!=NULL )
-	  g_free(script_path);
-	return;
+        if( script_path!=NULL )
+            g_free(script_path);
+        return;
     }
 
     /* Return if the backup script doesnt exist */
     if( ! file_exists(script_path) )
     {
-	info = g_strdup_printf(_("Error: Backup script doesnt exist.\n"));
-	show_info(info);
-	g_free(info);
+        info = g_strdup_printf(_("Error: Backup script doesnt exist.\n"));
+        show_info(info);
+        g_free(info);
 
-	g_free(script_path);
-	return;
+        g_free(script_path);
+        return;
     }
 
     /* Switch to the notebooks progress tab */
@@ -97,7 +97,7 @@ void backup_button_clicked(struct w *widgets)
     text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(widgets->progress_textview));
     gtk_text_buffer_set_text(text_buffer, utf8, -1);
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     g_free(info);
 
@@ -122,55 +122,54 @@ void run_process_command(struct w *widgets, gchar *cmd)
 
     /* Spawn the command */
     if( g_spawn_async_with_pipes(NULL,
-		        	 argv,
-		    		 NULL,
-		  G_SPAWN_SEARCH_PATH,
-				 NULL,
-	    		         NULL,
-		    	   &child_pid,
-		   // &standard_input,
-				 NULL,
-		     &standard_output,
-		      &standard_error,
-				 NULL) )
+                                 argv,
+                                 NULL,
+                  G_SPAWN_SEARCH_PATH,
+                                 NULL,
+                                 NULL,
+                           &child_pid,
+                   // &standard_input,
+                                 NULL,
+                     &standard_output,
+                      &standard_error,
+                                NULL) )
     {
-	/* Read standard output and insert in progress textview */
-	GIOChannel *output_channel = g_io_channel_unix_new(standard_output);
-	/* Accept binary, allow no buffering */
-	g_io_channel_set_encoding(output_channel, NULL, NULL);
-	/* Dont block, allowing gui redraws */
-	g_io_channel_set_flags(output_channel, G_IO_FLAG_NONBLOCK, NULL);
-	/* Poll and dispatch the output */
-	ret = g_io_add_watch(output_channel,
-		G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
-		    (GIOFunc)read_process_output, widgets);
-	if( ! ret )
-	  printf("Error: Can not add a watch for the output channel.\n");
+        /* Read standard output and insert in progress textview */
+        GIOChannel *output_channel = g_io_channel_unix_new(standard_output);
+        /* Accept binary, allow no buffering */
+        g_io_channel_set_encoding(output_channel, NULL, NULL);
+        /* Dont block, allowing gui redraws */
+        g_io_channel_set_flags(output_channel, G_IO_FLAG_NONBLOCK, NULL);
+        /* Poll and dispatch the output */
+        ret = g_io_add_watch(output_channel,
+                             G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
+                                 (GIOFunc)read_process_output, widgets);
+        if( ! ret )
+            printf("Error: Can not add a watch for the output channel.\n");
 
-	g_io_channel_unref(output_channel);
+        g_io_channel_unref(output_channel);
 
-	/* Read standard error and insert in progress textview */
-	GIOChannel *error_channel = g_io_channel_unix_new(standard_error);
-	/* Accept binary, allow no buffering */
-	g_io_channel_set_encoding(error_channel, NULL, NULL);
-	/* Dont block, allowing gui redraws */
-	g_io_channel_set_flags(error_channel, G_IO_FLAG_NONBLOCK, NULL);
-	/* Poll and dispatch the output */
-	ret = g_io_add_watch(error_channel, 
-		G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
-		     (GIOFunc)read_process_error, widgets);
-	if( ! ret )
-	  printf("Error: Can not add a watch for the error channel.\n");
+        /* Read standard error and insert in progress textview */
+        GIOChannel *error_channel = g_io_channel_unix_new(standard_error);
+        /* Accept binary, allow no buffering */
+        g_io_channel_set_encoding(error_channel, NULL, NULL);
+        /* Dont block, allowing gui redraws */
+        g_io_channel_set_flags(error_channel, G_IO_FLAG_NONBLOCK, NULL);
+        /* Poll and dispatch the output */
+        ret = g_io_add_watch(error_channel, 
+        G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
+             (GIOFunc)read_process_error, widgets);
+        if( ! ret )
+            printf("Error: Can not add a watch for the error channel.\n");
 
-	g_io_channel_unref(error_channel);
+        g_io_channel_unref(error_channel);
 
-	g_spawn_close_pid(child_pid);
+        g_spawn_close_pid(child_pid);
     }
     g_strfreev(argv);
 }
 
 
-
 gboolean read_process_output(GIOChannel *channel, GIOCondition condition, struct w *widgets)
 {
     GIOStatus status;
@@ -186,25 +185,25 @@ gboolean read_process_output(GIOChannel *channel, GIOCondition condition, struct
 
     if( status!=G_IO_STATUS_NORMAL || line==NULL || error!=NULL )
     {
-	if( error )
-          g_error("Error reading %s\n", error->message);
+        if( error )
+            g_error("Error reading %s\n", error->message);
 
-	if( channel!=NULL )
-	  g_io_channel_shutdown(channel, TRUE, NULL);
+        if( channel!=NULL )
+            g_io_channel_shutdown(channel, TRUE, NULL);
 
-	channel = NULL;
+        channel = NULL;
 
-	if( line!=NULL )
-          g_free(line);
+        if( line!=NULL )
+            g_free(line);
 
-	return FALSE;
+        return FALSE;
     }
 
     /* Show the progress */
     show_progress(line, widgets);
 
     if( line!=NULL )
-      g_free(line);
+        g_free(line);
 
     return TRUE;
 }
@@ -221,25 +220,25 @@ gboolean read_process_error(GIOChannel *channel, GIOCondition condition, struct
 
     if( status!=G_IO_STATUS_NORMAL || line==NULL || error!=NULL )
     {
-	if( error )
-          g_error("Error reading %s\n", error->message);
+        if( error )
+            g_error("Error reading %s\n", error->message);
 
-	if( channel!=NULL )
-	  g_io_channel_shutdown(channel, TRUE, NULL);
+        if( channel!=NULL )
+            g_io_channel_shutdown(channel, TRUE, NULL);
 
-	channel = NULL;
+        channel = NULL;
 
-	if( line!=NULL )
-          g_free(line);
+        if( line!=NULL )
+            g_free(line);
 
-	return FALSE;
+        return FALSE;
     }
 
     /* Show the progress */
     show_progress(line, widgets);
 
     if( line!=NULL )
-      g_free(line);
+        g_free(line);
 
     return TRUE;
 }
@@ -265,21 +264,21 @@ void show_progress(gchar *line, struct w *widgets)
         gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(text_buffer), &iter);
 
         /* Append data to the textview at the location specified by iter */
-	gtk_text_buffer_insert(text_buffer, &iter, utf8, -1);
+        gtk_text_buffer_insert(text_buffer, &iter, utf8, -1);
 
-	/* Get the end iter from the buffer */
-	gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(text_buffer), &iter);
-	
-	/* Create a mark at the end of the buffer specified by iter */
-	mark = gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(text_buffer), mark_name, &iter, FALSE);
-	
-	/* Move the mark to the bottom of the textview then scroll to it */
-	gtk_text_view_move_mark_onscreen(GTK_TEXT_VIEW(widgets->progress_textview), mark);
-	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(widgets->progress_textview), mark, 0.4, TRUE, 0.0, 0.0);
+        /* Get the end iter from the buffer */
+        gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(text_buffer), &iter);
 
-	/* Delete the mark */
-	gtk_text_buffer_delete_mark(GTK_TEXT_BUFFER(text_buffer), mark);
+        /* Create a mark at the end of the buffer specified by iter */
+        mark = gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(text_buffer), mark_name, &iter, FALSE);
 
-	g_free(utf8);
+        /* Move the mark to the bottom of the textview then scroll to it */
+        gtk_text_view_move_mark_onscreen(GTK_TEXT_VIEW(widgets->progress_textview), mark);
+        gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(widgets->progress_textview), mark, 0.4, TRUE, 0.0, 0.0);
+
+        /* Delete the mark */
+        gtk_text_buffer_delete_mark(GTK_TEXT_BUFFER(text_buffer), mark);
+
+        g_free(utf8);
     }
 }
