@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,9 +40,9 @@
 #include "save_backup_settings.h"
 #include "key_handling.h"
 
-int global_backup_local		= 1;
-int global_backup_local_remote 	= 0;
-int global_backup_remote_local	= 0;
+int global_backup_local = 1;
+int global_backup_local_remote = 0;
+int global_backup_remote_local = 0;
 
 GtkTreeIter iter_filesel;
 
@@ -56,10 +56,10 @@ void backup_local_checkbutton_toggled(GtkButton *button, struct w *widgets)
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local)) )
     {
         global_backup_local        = 1;
-	global_backup_local_remote = 0;
-	global_backup_remote_local = 0;
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local_remote), FALSE);
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_remote_local), FALSE);
+        global_backup_local_remote = 0;
+        global_backup_remote_local = 0;
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local_remote), FALSE);
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_remote_local), FALSE);
     }
 }
 
@@ -67,12 +67,12 @@ void backup_local_checkbutton_toggled(GtkButton *button, struct w *widgets)
 void backup_local_remote_checkbutton_toggled(GtkButton *button, struct w *widgets)
 {
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local_remote)) )
-    {    
-        global_backup_local  	   = 0;
+    {
+        global_backup_local = 0;
         global_backup_local_remote = 1;
         global_backup_remote_local = 0;
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local), FALSE);
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_remote_local), FALSE);
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local), FALSE);
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_remote_local), FALSE);
     }
 }
 
@@ -80,12 +80,12 @@ void backup_local_remote_checkbutton_toggled(GtkButton *button, struct w *widget
 void backup_remote_local_checkbutton_toggled(GtkButton *button, struct w *widgets)
 {
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_remote_local)) )
-    {    
-        global_backup_local  	   = 0;
+    {
+        global_backup_local = 0;
         global_backup_local_remote = 0;
         global_backup_remote_local = 1;
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local), FALSE);
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local_remote), FALSE);
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local), FALSE);
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_local_remote), FALSE);
     }
 }
 
@@ -117,7 +117,7 @@ void src_filesel_ok(struct w *widgets)
     gtk_list_store_append(GTK_LIST_STORE(widgets->backup_store), &iter_filesel);
     gtk_list_store_set(widgets->backup_store, &iter_filesel, 1, utf8, -1);
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     /* Check the backup checkbutton in the treeview */
     gtk_list_store_set(widgets->backup_store, &iter_filesel, 6, TRUE, -1);
@@ -126,12 +126,12 @@ void src_filesel_ok(struct w *widgets)
 
     /* If destination is local, show dest file selector */
     if( global_backup_local )
-	show_dst_filesel(widgets);
+        show_dst_filesel(widgets);
     else
     if( global_backup_local_remote )
-      show_server_menu("dest", widgets);
+        show_server_menu("dest", widgets);
     else
-      printf("This is 2 odd.\n");
+        printf("src_filesel_ok error.\n");
 }
 
 
@@ -150,7 +150,7 @@ void dst_filesel_ok(struct w *widgets)
     gtk_list_store_set(widgets->backup_store, &iter_filesel, 6, TRUE, -1);
 
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     gtk_widget_destroy(widgets->dst_filesel);
 
@@ -165,29 +165,29 @@ void show_src_filesel(struct w *widgets)
     /* Source is remote */
     if( global_backup_remote_local )
     {
-	/* Show source server selection */
-	show_server_menu("source", widgets);
+        /* Show source server selection */
+        show_server_menu("source", widgets);
+
+        if( GTK_IS_WINDOW(widgets->backup_menu_window) )
+            gtk_widget_destroy(widgets->backup_menu_window);
 
-	if( GTK_IS_WINDOW(widgets->backup_menu_window) )
-          gtk_widget_destroy(widgets->backup_menu_window);
-          
         return;
     }
-    
+
     /* Show the source file selection */
     widgets->src_filesel = gtk_file_selection_new("Select source directory or file.");
     gtk_widget_show(widgets->src_filesel);
 
     /* Connect the ok button to the file selection ok function */
     g_signal_connect_swapped(G_OBJECT(GTK_FILE_SELECTION(widgets->src_filesel)->ok_button), "clicked",
-                    	     G_CALLBACK(src_filesel_ok), widgets);
-                        	          
+                                                                   G_CALLBACK(src_filesel_ok), widgets);
+
     /* Cancel button destroys the fileselection widget */
     g_signal_connect_swapped(G_OBJECT(GTK_FILE_SELECTION(widgets->src_filesel)->cancel_button),
-                        "clicked", G_CALLBACK(src_filesel_cancel), widgets);
+                                             "clicked", G_CALLBACK(src_filesel_cancel), widgets);
 
     if( GTK_IS_WINDOW(widgets->backup_menu_window) )
-      gtk_widget_destroy(widgets->backup_menu_window);
+        gtk_widget_destroy(widgets->backup_menu_window);
 }
 
 
@@ -200,75 +200,75 @@ void show_dst_filesel(struct w *widgets)
     /* Destination is remote */
     if( global_backup_local_remote )
     {
-	/* Show destination server selection */
-	show_server_menu("dest", widgets);
+        /* Show destination server selection */
+        show_server_menu("dest", widgets);
+
+        if( GTK_IS_WINDOW(widgets->backup_menu_window) )
+            gtk_widget_destroy(widgets->backup_menu_window);
 
-	if( GTK_IS_WINDOW(widgets->backup_menu_window) )
-          gtk_widget_destroy(widgets->backup_menu_window);
-          
         return;
     }
-    
+
     /* Save source server selection */
     if( global_backup_remote_local )
     {
-	/* Insert source server data into the treeview and upload keys */
-	host    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_server_entry));
-	path    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_path_entry));
-	port    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_port_entry));
-	user    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_user_entry));
-	pass    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_password_entry));
-	keytype = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widgets->key_type_combo));
-	keylen  = gtk_entry_get_text(GTK_ENTRY(widgets->key_length_spinbutton));
+        /* Insert source server data into the treeview and upload keys */
+        host    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_server_entry));
+        path    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_path_entry));
+        port    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_port_entry));
+        user    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_user_entry));
+        pass    = gtk_entry_get_text(GTK_ENTRY(widgets->remote_password_entry));
+        keytype = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widgets->key_type_combo));
+        keylen  = gtk_entry_get_text(GTK_ENTRY(widgets->key_length_spinbutton));
 
-	if( is_empty((gchar *)host)  ||  is_empty((gchar *)path)
-	||  is_empty((gchar *)port)  ||  is_empty((gchar *)user)
-	||  is_empty((gchar *)pass)  ||  is_empty((gchar *)keytype)
-	||  is_empty((gchar *)keylen) )
-	{
-	    info = g_strdup_printf(_("All fields must be filled in correctly.\n"));
-	    show_info(info);
-	    if( info!=NULL )
-	      g_free(info);
+        if( is_empty((gchar *)host)  ||  is_empty((gchar *)path)
+        ||  is_empty((gchar *)port)  ||  is_empty((gchar *)user)
+        ||  is_empty((gchar *)pass)  ||  is_empty((gchar *)keytype)
+        ||  is_empty((gchar *)keylen) )
+        {
+            info = g_strdup_printf(_("All fields must be filled in correctly.\n"));
+            show_info(info);
+            if( info!=NULL )
+                g_free(info);
 
-	    return;    
-	}
+            return;
+        }
 
-	/* Generate and setup keys if there are no keys for this host */
-	if( ! setup_keys((char *)user, (char *)pass, (char *)host, (char *)port, (char *)keytype, (char *)keylen, widgets) )
-	{
-	    info = g_strdup_printf(_("Could not upload public key to the remote host.\nMake sure that the remote ssh server is started and that all settings are correct.\n"));
-	    show_info(info);
-	    if( info!=NULL )
-	      g_free(info);
+        /* Generate and setup keys if there are no keys for this host */
+        if( ! setup_keys((char *)user, (char *)pass, (char *)host, (char *)port, (char *)keytype, (char *)keylen, widgets) )
+        {
+            info = g_strdup_printf(_("Could not upload public key to the remote host.\nMake sure that the remote ssh server is started and that all settings are correct.\n"));
+            show_info(info);
+            if( info!=NULL )
+                g_free(info);
 
-	    return;    
-	}
+            return;
+        }
 
-	key_name_priv = mk_key_name((char *)user, (char *)host, "priv");
-	key_path_priv = g_strdup_printf("%s/%s", global_key_path, key_name_priv);
-	g_free(key_name_priv);
+        key_name_priv = mk_key_name((char *)user, (char *)host, "priv");
+        key_path_priv = g_strdup_printf("%s/%s", global_key_path, key_name_priv);
+        g_free(key_name_priv);
 
-	/* Insert the backup source in the treeview row */
-	gtk_list_store_append(GTK_LIST_STORE(widgets->backup_store), &iter_filesel);
+        /* Insert the backup source in the treeview row */
+        gtk_list_store_append(GTK_LIST_STORE(widgets->backup_store), &iter_filesel);
 
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 0, host, -1);
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 1, path, -1);
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 8, user, -1);
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 9, port, -1);
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 10, key_path_priv, -1);
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 0, host, -1);
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 1, path, -1);
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 8, user, -1);
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 9, port, -1);
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 10, key_path_priv, -1);
 
-	/* Check the backup checkbutton in the treeview */
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 6, TRUE, -1);
+        /* Check the backup checkbutton in the treeview */
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 6, TRUE, -1);
 
-	g_free(key_path_priv);
+        g_free(key_path_priv);
 
-	/* Check the backup checkbutton in the treeview */
-	gtk_list_store_set(widgets->backup_store, &iter_filesel, 6, TRUE, -1);
+        /* Check the backup checkbutton in the treeview */
+        gtk_list_store_set(widgets->backup_store, &iter_filesel, 6, TRUE, -1);
 
-	if( GTK_IS_WINDOW(widgets->server_menu_window) )
-          gtk_widget_destroy(widgets->server_menu_window);
-	/* Dont return */    
+        if( GTK_IS_WINDOW(widgets->server_menu_window) )
+            gtk_widget_destroy(widgets->server_menu_window);
+        /* Dont return */
     }
 
     /* Show the destination file selection */
@@ -277,11 +277,11 @@ void show_dst_filesel(struct w *widgets)
 
     /* Connect the ok button to the file selection ok function */
     g_signal_connect_swapped(G_OBJECT(GTK_FILE_SELECTION(widgets->dst_filesel)->ok_button), "clicked",
-                    	     G_CALLBACK(dst_filesel_ok), widgets);
-                        	          
+                                                                   G_CALLBACK(dst_filesel_ok), widgets);
+
     /* Cancel button destroys the fileselection widget */
     g_signal_connect_swapped(G_OBJECT(GTK_FILE_SELECTION(widgets->dst_filesel)->cancel_button),
-                        "clicked", G_CALLBACK(dst_filesel_cancel), widgets);
+                                             "clicked", G_CALLBACK(dst_filesel_cancel), widgets);
 }
 
 
@@ -305,11 +305,11 @@ void dest_server_forward_clicked(struct w *widgets)
     ||  is_empty((gchar *)pass)  ||  is_empty((gchar *)keytype)
     ||  is_empty((gchar *)keylen) )
     {
-	info = g_strdup_printf(_("All fields must be filled in.\n"));
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
-	return;    
+        info = g_strdup_printf(_("All fields must be filled in.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
+        return;
     }
 
     key_name_priv = mk_key_name((char *)user, (char *)host, "priv");
@@ -330,12 +330,12 @@ void dest_server_forward_clicked(struct w *widgets)
     /* Generate and setup keys if there are no keys for this host */
     if( ! setup_keys((char *)user, (char *)pass, (char *)host, (char *)port, (char *)keytype, (char *)keylen, widgets) )
     {
-	info = g_strdup_printf(_("Could not upload public key to the remote host.\nMake sure that the remote ssh server is started and that all settings are correct.\n"));
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Could not upload public key to the remote host.\nMake sure that the remote ssh server is started and that all settings are correct.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
-	return;    
+        return;
     }
 
     /* Save the backup settings */
@@ -379,14 +379,13 @@ void show_server_menu(char type[128], struct w *widgets)
 
     /* Set window information */
     if( strstr(type, "source") )
-	info = g_strdup_printf(_("GAdmin-Rsync %s source server selection"), VERSION);
+        info = g_strdup_printf(_("GAdmin-Rsync %s source server selection"), VERSION);
     else
-	info = g_strdup_printf(_("GAdmin-Rsync %s destination server selection"), VERSION);
-    
+        info = g_strdup_printf(_("GAdmin-Rsync %s destination server selection"), VERSION);
+
     gtk_window_set_title(GTK_WINDOW(widgets->server_menu_window), info);
     g_free(info);
 
-
     menu_vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(widgets->server_menu_window), menu_vbox);
 
@@ -396,9 +395,9 @@ void show_server_menu(char type[128], struct w *widgets)
     table1 = gtk_table_new(2, 2, FALSE);
 
     if( strstr(type, "source") )
-	frame1 = gtk_frame_new(_("Supply source server information:"));
+        frame1 = gtk_frame_new(_("Supply source server information:"));
     else
-	frame1 = gtk_frame_new(_("Supply destination server information:"));
+        frame1 = gtk_frame_new(_("Supply destination server information:"));
 
     gtk_box_pack_start(GTK_BOX(menu_vbox), frame1, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame1), table1);
@@ -428,17 +427,17 @@ void show_server_menu(char type[128], struct w *widgets)
     utf8 = g_locale_to_utf8(text, strlen(text), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->remote_port_entry), utf8);
     if( text!=NULL )
-      g_free(text);
+        g_free(text);
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     text = g_strdup_printf("%s", g_get_user_name());
     utf8 = g_locale_to_utf8(text, strlen(text), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->remote_user_entry), utf8);
     if( text!=NULL )
-      g_free(text);
+        g_free(text);
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->key_length_spinbutton), 1024);
 
@@ -448,21 +447,19 @@ void show_server_menu(char type[128], struct w *widgets)
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->key_type_combo), utf8);
     gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->key_type_combo), 0);
     if( text!=NULL )
-      g_free(text);
+        g_free(text);
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     text = g_strdup_printf("rsa");
     utf8 = g_locale_to_utf8(text, strlen(text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->key_type_combo), utf8);
     if( text!=NULL )
-      g_free(text);
+        g_free(text);
     if( utf8!=NULL )
-      g_free(utf8);
-
-
-//    FIXME: Add a progress bar after the key type row on the same line.
+        g_free(utf8);
 
+//    FIX: Add a progress bar after the key type row on the same line.
 
     /* Buttons, "Cancel", "Forward"*/
     GtkWidget *hbutton_box = gtk_hbutton_box_new();
@@ -481,28 +478,25 @@ void show_server_menu(char type[128], struct w *widgets)
     g_signal_connect(GTK_WINDOW(widgets->server_menu_window), "delete_event",
                      G_CALLBACK(gtk_widget_destroy), NULL);
 
-
-
     /* Quit / Cancel button */
     g_signal_connect_swapped((gpointer)cancel_button, "clicked",
-                    	    G_CALLBACK(gtk_widget_destroy),
-                            GTK_OBJECT(widgets->server_menu_window));
+                                 G_CALLBACK(gtk_widget_destroy),
+                         GTK_OBJECT(widgets->server_menu_window));
 
     /* Forward button signals */
-    
+
     /* We are asked to show a source server selection */
     if( strstr(type, "source") )
     {
         /* Pressing the forward button shows a destination selection */
-	g_signal_connect_swapped((gpointer)forward_button, "clicked",
-                    		G_CALLBACK(show_dst_filesel), widgets);
+        g_signal_connect_swapped((gpointer)forward_button, "clicked",
+                                G_CALLBACK(show_dst_filesel), widgets);
     }
     else /* We are asked to show a destination server selection */
     {
-	g_signal_connect_swapped((gpointer)forward_button, "clicked",
-                    		G_CALLBACK(dest_server_forward_clicked), widgets);
+        g_signal_connect_swapped((gpointer)forward_button, "clicked",
+                     G_CALLBACK(dest_server_forward_clicked), widgets);
     }
-    
 
     gtk_widget_show_all(widgets->server_menu_window);
 }
@@ -530,7 +524,7 @@ void show_backup_menu(struct w *widgets)
     g_free(info);
 
     g_signal_connect(GTK_WINDOW(widgets->backup_menu_window), "delete_event",
-                     G_CALLBACK(gtk_widget_destroy), NULL);
+                                         G_CALLBACK(gtk_widget_destroy), NULL);
 
     menu_vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(widgets->backup_menu_window), menu_vbox);
@@ -551,7 +545,7 @@ void show_backup_menu(struct w *widgets)
     a++; b++;
     widgets->backup_chkbtn_remote_local = make_checkbutton_with_label(GTK_TABLE(table1), _("Remote to local backup:"), 0,1,a,b);
     a++; b++;
-	      
+
     /* Buttons, "Cancel", "Forward"*/
     GtkWidget *hbutton_box = gtk_hbutton_box_new();
     gtk_button_box_set_layout(GTK_BUTTON_BOX(hbutton_box), GTK_BUTTONBOX_SPREAD);
@@ -570,30 +564,30 @@ void show_backup_menu(struct w *widgets)
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->backup_chkbtn_remote_local), FALSE);
 
     /* We need to reset global_backup* options so that it matches the default settings */
-    global_backup_local   	= 1;
+    global_backup_local = 1;
     global_backup_local_remote  = 0;
     global_backup_remote_local  = 0;
 
     /* Signal hookups for the checkbuttons, all uses the same function to set globals */
     g_signal_connect((gpointer)widgets->backup_chkbtn_local, "toggled",
-                	    G_CALLBACK(backup_local_checkbutton_toggled), widgets);
+                  G_CALLBACK(backup_local_checkbutton_toggled), widgets);
 
     g_signal_connect((gpointer)widgets->backup_chkbtn_local_remote, "toggled",
-                	    G_CALLBACK(backup_local_remote_checkbutton_toggled), widgets);
+                  G_CALLBACK(backup_local_remote_checkbutton_toggled), widgets);
 
     g_signal_connect((gpointer)widgets->backup_chkbtn_remote_local, "toggled",
-                	    G_CALLBACK(backup_remote_local_checkbutton_toggled), widgets);
+                  G_CALLBACK(backup_remote_local_checkbutton_toggled), widgets);
 
     /* Quit button */
     g_signal_connect_swapped((gpointer)cancel_button, "clicked",
-                    	    G_CALLBACK(gtk_widget_destroy),
-                            GTK_OBJECT(widgets->backup_menu_window));
+                                 G_CALLBACK(gtk_widget_destroy),
+                                 GTK_OBJECT(widgets->backup_menu_window));
     /* Forward button */
     g_signal_connect_swapped((gpointer)forward_button, "clicked",
-                    	    G_CALLBACK(show_src_filesel), widgets);
+                            G_CALLBACK(show_src_filesel), widgets);
 
     gtk_widget_show_all(widgets->backup_menu_window);
 
     if( utf8 != NULL )
-      g_free(utf8);
+        g_free(utf8);
 }
