@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 */
 
 
-
 #ifdef HAVE_CONFIG_H
 #  include "../config.h"
 #endif
@@ -33,14 +32,13 @@
 #include "restore_menu.h"
 
 
-
 void create_main_window(struct w *widgets)
 {
     gchar *info, *pixmap_directory;
     GtkCellRenderer *pixbuf_cell_renderer;
     GdkPixbuf *pixbuf;
 
-    /* Create the main window */    
+    /* Create the main window */
     widgets->main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW (widgets->main_window), GTK_WIN_POS_CENTER);
     gtk_widget_set_size_request(widgets->main_window, 620, 430);
@@ -50,16 +48,16 @@ void create_main_window(struct w *widgets)
     gtk_window_set_title(GTK_WINDOW(widgets->main_window), info);
     g_free(info);
 
-    /* Set the main window icon */    
+    /* Set the main window icon */
     pixmap_directory = g_strdup_printf("%s/pixmaps/gadmin-rsync", PACKAGE_DATA_DIR);
     add_pixmap_directory(pixmap_directory);
     g_free(pixmap_directory);
 
-    pixbuf_cell_renderer = gtk_cell_renderer_pixbuf_new();    
+    pixbuf_cell_renderer = gtk_cell_renderer_pixbuf_new();
     pixbuf = create_pixbuf("gadmin-rsync.png");
     g_object_set(pixbuf_cell_renderer, "pixbuf", pixbuf, NULL); 
     gtk_window_set_icon(GTK_WINDOW(widgets->main_window), pixbuf);
-    gdk_pixbuf_unref(pixbuf);
+    g_object_unref(pixbuf);
 
     widgets->main_vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(widgets->main_window), widgets->main_vbox);
@@ -84,73 +82,70 @@ void create_main_window(struct w *widgets)
 
     gtk_toolbar_set_style(GTK_TOOLBAR(main_toolbar), GTK_TOOLBAR_BOTH);
 
-    /* Run selected backup button */    
-    GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes", 
+    /* Run selected backup button */
+    GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes",
                                   gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *backup_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Run selected backup"), 
-							  NULL, NULL,
-							  toolbar_icon_yes, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(backup_button), "clicked", 
+                                                           GTK_TOOLBAR_CHILD_BUTTON,
+                                                     NULL, _("Run selected backup"),
+                                                                         NULL, NULL,
+                                                        toolbar_icon_yes, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(backup_button), "clicked",
                              G_CALLBACK(backup_button_clicked), widgets);
 
     /* Cancel backup button */
-    GtkWidget *toolbar_icon_no = gtk_image_new_from_stock("gtk-cancel", 
+    GtkWidget *toolbar_icon_no = gtk_image_new_from_stock("gtk-cancel",
                                  gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *cancel_backup_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Cancel backup"),
-							  NULL, NULL,
-							  toolbar_icon_no, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(cancel_backup_button), "clicked", 
+                                                          NULL, _("Cancel backup"),
+                                                                        NULL, NULL,
+                                                        toolbar_icon_no, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(cancel_backup_button), "clicked",
                              G_CALLBACK(cancel_process_clicked), widgets);
 
     /* Restore selected backup button */
-    GtkWidget *toolbar_icon_restore = gtk_image_new_from_stock("gtk-yes", 
+    GtkWidget *toolbar_icon_restore = gtk_image_new_from_stock("gtk-yes",
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *restore_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
-                                                          GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Restore from selection"),
-							  NULL, NULL,
-							  toolbar_icon_restore, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(restore_button), "clicked", 
+                                                            GTK_TOOLBAR_CHILD_BUTTON,
+                                                   NULL, _("Restore from selection"),
+                                                                          NULL, NULL,
+                                                     toolbar_icon_restore, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(restore_button), "clicked",
                              G_CALLBACK(show_restore_menu), widgets);
 
-
     /* Help button */
     GtkWidget *toolbar_icon_help = gtk_image_new_from_stock("gtk-help", 
                                    gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *help_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Help"),
-							  NULL, NULL,
-							  toolbar_icon_help, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(help_button), "clicked", 
+                                                                   NULL, _("Help"),
+                                                                        NULL, NULL,
+                                                      toolbar_icon_help, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(help_button), "clicked",
                              G_CALLBACK(show_help), widgets);
 
-
     /* About button */
-    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-about", 
+    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-about",
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *about_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("About"),
-							  NULL, NULL,
-							  toolbar_icon_about, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(about_button), "clicked", 
+                                                                  NULL, _("About"),
+                                                                        NULL, NULL,
+                                                     toolbar_icon_about, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(about_button), "clicked",
                              G_CALLBACK(show_credits), widgets);
 
-
     /* Quit button */
-    GtkWidget *toolbar_icon_quit = gtk_image_new_from_stock("gtk-quit", 
+    GtkWidget *toolbar_icon_quit = gtk_image_new_from_stock("gtk-quit",
                                    gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *quit_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Quit"),
-							  NULL, NULL,
-							  toolbar_icon_quit, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(quit_button), "clicked", 
+                                                                   NULL, _("Quit"),
+                                                                        NULL, NULL,
+                                                      toolbar_icon_quit, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(quit_button), "clicked",
                              G_CALLBACK(gtk_main_quit), NULL);
 
     /* The notebook */
