@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,10 +52,7 @@ extern gulong backup_combo_changed_signal;
 
 
 /* Change cell text in a treeview */
-void cell_edited(GtkCellRendererText *cell,
-		        gchar *path_string,
-			   gchar *new_text,
-			  struct w *widgets)
+void cell_edited(GtkCellRendererText *cell, gchar *path_string, gchar *new_text, struct w *widgets)
 {
     GtkTreeIter iter;
     GtkTreePath *path=NULL;
@@ -67,7 +64,7 @@ void cell_edited(GtkCellRendererText *cell,
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->backup_store), &iter, path);
 
     if( path!=NULL )
-      gtk_tree_path_free(path);
+        gtk_tree_path_free(path);
 
     gtk_list_store_set(GTK_LIST_STORE(widgets->backup_store), &iter, column, new_text, -1);
 }
@@ -82,18 +79,18 @@ void treeview_toggle_button_clicked(GtkCellRendererToggle *cell_renderer, gchar
     treepath = gtk_tree_path_new_from_string(path);
     GtkTreeModel *model;
     int col_num;
-    
+
     col_num = (int) g_object_get_data(G_OBJECT(cell_renderer), "column");
-    
+
     gtk_tree_model_get_iter(GTK_TREE_MODEL(widgets->backup_store), &iter, treepath);
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets->backup_treeview));
 
     /* Toggle it to the opposite checked state */
     gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, col_num, &val, -1);
     if( val )
-	gtk_list_store_set(widgets->backup_store, &iter, col_num, FALSE, -1);
+        gtk_list_store_set(widgets->backup_store, &iter, col_num, FALSE, -1);
     else
-	gtk_list_store_set(widgets->backup_store, &iter, col_num, TRUE, -1);
+        gtk_list_store_set(widgets->backup_store, &iter, col_num, TRUE, -1);
 
     gtk_tree_path_free(treepath);
 }
@@ -105,23 +102,23 @@ void del_treeview_row(struct w *widgets)
     GtkTreeSelection *selection;
     GtkTreeModel *model;
     GtkTreeIter iter;
-    gboolean val, edit=0;
+    gboolean val = 0, edit = 0;
     GtkTreePath *path;
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widgets->backup_treeview));
     if( selection )
     {
-	val = gtk_tree_selection_get_selected(GTK_TREE_SELECTION(selection), &model, &iter);
+        val = gtk_tree_selection_get_selected(GTK_TREE_SELECTION(selection), &model, &iter);
 
-	if( gtk_list_store_iter_is_valid(GTK_LIST_STORE(model), &iter) )
-	  gtk_list_store_remove(widgets->backup_store, &iter);
+        if( gtk_list_store_iter_is_valid(GTK_LIST_STORE(model), &iter) )
+            gtk_list_store_remove(widgets->backup_store, &iter);
 
-	path = gtk_tree_path_new_first();
+        path = gtk_tree_path_new_first();
 
-	if( path )
-	  gtk_tree_view_set_cursor(GTK_TREE_VIEW(widgets->backup_treeview), path, NULL, edit);
+        if( path )
+            gtk_tree_view_set_cursor(GTK_TREE_VIEW(widgets->backup_treeview), path, NULL, edit);
 
-	gtk_tree_path_free(path);
+        gtk_tree_path_free(path);
     }
 }
 
@@ -133,14 +130,14 @@ void backup_name_combo_changed(struct w *widgets)
 
     /* Clear schedule days combo boxes */
     for(i=0; i<8; i++)
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i]), FALSE);
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i]), FALSE);
 
     /* Clear schedule time combo box */
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[8]), FALSE);
 
     /* Set schedule spinbuttons to default time */
     for(i=0; i<2; i++)
-      gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[i]), 1);
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[i]), 1);
 
 
     populate_rsync_tab(widgets);
@@ -161,21 +158,20 @@ void create_new_backup(struct w *widgets)
         info = g_strdup_printf(_("The backup name is too short.\n"));
         show_info(info);
         g_free(info);
-	return;
+        return;
     }
 
     /* Fixme: Some chars cannot be used in the backup name. */
     for(i=0; backup_name[i]!='\0'; i++)
     {
-	if( backup_name[i]=='/'  || backup_name[i]=='\r'
-	||  backup_name[i]=='\n' || backup_name[i]=='\t' )
-	{
-    	    info = g_strdup_printf(_("The backup name contains special chars that cannot be used.\n"));
-    	    show_info(info);
-    	    g_free(info);
-	    return;	
-	}
-    
+        if( backup_name[i]=='/'  || backup_name[i]=='\r'
+        ||  backup_name[i]=='\n' || backup_name[i]=='\t' )
+        {
+            info = g_strdup_printf(_("The backup name contains special chars that cannot be used.\n"));
+            show_info(info);
+            g_free(info);
+            return;
+        }
     }
 
     /* Create a new backup settings file */
@@ -188,7 +184,7 @@ void create_new_backup(struct w *widgets)
         show_info(info);
         g_free(info);
         g_free(conf_file);
-	return;
+        return;
     }
 
     /* Write the new settings file */
@@ -217,7 +213,7 @@ void create_new_backup(struct w *widgets)
 
     gtk_widget_destroy(widgets->new_backup_window);
 
-    /* Show backup type menu selection */    
+    /* Show backup type menu selection */
     show_backup_menu(widgets);
 }
 
@@ -241,8 +237,8 @@ void delete_backup(struct w *widgets)
     /* Delete the settings file */
     if( conf_file!=NULL )
     {
-	unlink(conf_file);
-	g_free(conf_file);
+        unlink(conf_file);
+        g_free(conf_file);
     }
 
     /* Delete the schedule script if any */
@@ -318,7 +314,8 @@ void create_new_backup_window(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), table);
 
-    widgets->new_backup_entry = make_entry_with_label(GTK_TABLE(table), _(" The name of the new backup: "), 0,1,0,1, 300);
+    widgets->new_backup_entry = make_entry_with_label(GTK_TABLE(table),
+                       _(" The name of the new backup: "), 0,1,0,1, 300);
 
     /* Apply and cancel buttons */
     GtkWidget *hbuttonbox = gtk_hbutton_box_new();
@@ -327,13 +324,13 @@ void create_new_backup_window(struct w *widgets)
 
     GtkWidget *cancel_button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), cancel_button);
-    g_signal_connect_swapped(G_OBJECT(cancel_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(cancel_button), "clicked",
              G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(widgets->new_backup_window));
 
     GtkWidget *apply_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), apply_button);
-    g_signal_connect_swapped(G_OBJECT(apply_button), "clicked", 
-                               G_CALLBACK(create_new_backup), widgets);
+    g_signal_connect_swapped(G_OBJECT(apply_button), "clicked",
+                         G_CALLBACK(create_new_backup), widgets);
 
     gtk_widget_show_all(widgets->new_backup_window);
 }
@@ -362,9 +359,8 @@ void create_rsync_tab(struct w *widgets)
 
     widgets->user_settings_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(user_settings_treeview_hbox), widgets->user_settings_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window), 
-						    GTK_POLICY_NEVER, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window),
+                                                            GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(widgets->user_settings_scrolled_window, -1, 100);
 
@@ -375,17 +371,16 @@ void create_rsync_tab(struct w *widgets)
     /* Create the directory treeview in the user settings scrolled window */
     directory_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), directory_scrolled_window, FALSE, FALSE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(directory_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(directory_scrolled_window),
+                                           GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(directory_scrolled_window, -1, 120);
 
     /* 11 columns */
     widgets->backup_store = gtk_list_store_new(11, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-						   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-						   G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_STRING,
-						   G_TYPE_STRING, G_TYPE_STRING);
+                                                   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+                                                 G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_STRING,
+                                                                   G_TYPE_STRING, G_TYPE_STRING);
 
     widgets->backup_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->backup_treeview), GTK_TREE_MODEL(widgets->backup_store));
@@ -414,7 +409,7 @@ void create_rsync_tab(struct w *widgets)
     gtk_label_set_justify(GTK_LABEL(label230), GTK_JUSTIFY_LEFT);
     /* The add file or directory signal hookup */
     g_signal_connect_swapped(add_backup_button, "clicked",
-                    	     G_CALLBACK(show_backup_menu), widgets);
+                     G_CALLBACK(show_backup_menu), widgets);
     gtk_box_pack_start(GTK_BOX(hbuttonbox1), add_backup_button, TRUE, TRUE, 0);
 
 
@@ -432,66 +427,65 @@ void create_rsync_tab(struct w *widgets)
     gtk_label_set_justify(GTK_LABEL(label234), GTK_JUSTIFY_LEFT);
     /* Remove data selection signal hookup */
     g_signal_connect_swapped(del_backup_row_button, "clicked",
-                    	     G_CALLBACK(del_treeview_row), widgets);
+                         G_CALLBACK(del_treeview_row), widgets);
     gtk_box_pack_start(GTK_BOX(hbuttonbox1), del_backup_row_button, TRUE, TRUE, 0);
 
 
     /* Setup the treeview cells to be editable or clickable */
     src_host_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(src_host_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(src_host_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(src_host_cell_renderer, "edited",
+                     G_CALLBACK(cell_edited), widgets);
 
     src_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(src_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(src_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(src_cell_renderer, "edited",
+                 G_CALLBACK(cell_edited), widgets);
 
     dst_host_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(dst_host_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(dst_host_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(dst_host_cell_renderer, "edited",
+                      G_CALLBACK(cell_edited), widgets);
 
     dst_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(dst_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(dst_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(dst_cell_renderer, "edited",
+                 G_CALLBACK(cell_edited), widgets);
 
     include_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(include_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(include_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(include_cell_renderer, "edited",
+                     G_CALLBACK(cell_edited), widgets);
 
     exclude_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(exclude_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(exclude_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(exclude_cell_renderer, "edited",
+                     G_CALLBACK(cell_edited), widgets);
 
     incl_backup_cell_renderer = gtk_cell_renderer_toggle_new();
     g_object_set(incl_backup_cell_renderer, "activatable", TRUE, NULL);
-    g_signal_connect(incl_backup_cell_renderer, "toggled",  
-		      G_CALLBACK(treeview_toggle_button_clicked), widgets);
+    g_signal_connect(incl_backup_cell_renderer, "toggled",
+       G_CALLBACK(treeview_toggle_button_clicked), widgets);
 
     delete_dest_cell_renderer = gtk_cell_renderer_toggle_new();
     g_object_set(delete_dest_cell_renderer, "activatable", TRUE, NULL);
-    g_signal_connect(delete_dest_cell_renderer, "toggled",  
-		      G_CALLBACK(treeview_toggle_button_clicked), widgets);
+    g_signal_connect(delete_dest_cell_renderer, "toggled",
+       G_CALLBACK(treeview_toggle_button_clicked), widgets);
 
     user_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(user_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(user_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(user_cell_renderer, "edited",
+                  G_CALLBACK(cell_edited), widgets);
 
     port_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(port_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(port_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
+    g_signal_connect(port_cell_renderer, "edited",
+                  G_CALLBACK(cell_edited), widgets);
 
     priv_key_path_cell_renderer = gtk_cell_renderer_text_new();
     g_object_set(priv_key_path_cell_renderer, "editable", TRUE, NULL);
-    g_signal_connect(priv_key_path_cell_renderer, "edited",  
-		      G_CALLBACK(cell_edited), widgets);
-
+    g_signal_connect(priv_key_path_cell_renderer, "edited",
+                           G_CALLBACK(cell_edited), widgets);
 
     colnr  = 0;
 
@@ -558,7 +552,7 @@ void create_rsync_tab(struct w *widgets)
     /* Add a settings frame in a table */
     frame = gtk_frame_new("");
 
-    /* A table with NUM settings and 2 columns FIXME, Count */
+    /* A table with NUM settings and 2 columns. Fix count */
     widgets->usr_set_table = gtk_table_new(NUM_USERTAB_ENTRIES+NUM_USERTAB_SPINBUTTONS+NUM_USERTAB_CHECKBUTTONS+NUM_USERTAB_COMBOS, 2, FALSE);
     gtk_box_pack_start(GTK_BOX(widgets->user_settings_vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), widgets->usr_set_table);
@@ -585,7 +579,7 @@ void create_rsync_tab(struct w *widgets)
 
     /* Delete selected backup signal hookup */
     g_signal_connect_swapped(del_backup_button, "clicked",
-            	        G_CALLBACK(delete_backup), widgets);
+                        G_CALLBACK(delete_backup), widgets);
 
     /* Selected backup combo */
     utf8 = g_locale_to_utf8(_(" Selected backup: "), -1, NULL, NULL, NULL);
@@ -593,7 +587,7 @@ void create_rsync_tab(struct w *widgets)
 
     /* Callback for combo changed. */
     backup_combo_changed_signal = g_signal_connect_swapped(widgets->rsync_set_combo[0], "changed",
-    		    				    G_CALLBACK(backup_name_combo_changed), widgets);
+                                                    G_CALLBACK(backup_name_combo_changed), widgets);
 
     a++; b++;
 
@@ -623,7 +617,7 @@ void create_rsync_tab(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbuttonbox2), create_new_backup_button, FALSE, FALSE, 0);
     /* The create new backup signal hookup */
     g_signal_connect_swapped(create_new_backup_button, "clicked",
-                    	     G_CALLBACK(create_new_backup_window), widgets);
+                    G_CALLBACK(create_new_backup_window), widgets);
 
 
     /* Save backup button */
@@ -642,7 +636,7 @@ void create_rsync_tab(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbuttonbox2), save_backup_button, FALSE, FALSE, 0);
     /* Save backup button signal hookup */
     g_signal_connect_swapped(save_backup_button, "clicked",
-                    	     G_CALLBACK(save_backup_settings), widgets);
+                  G_CALLBACK(save_backup_settings), widgets);
     a++; b++;
 
 
@@ -662,7 +656,7 @@ void create_rsync_tab(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbuttonbox2), log_backup_button, FALSE, FALSE, 0);
     /* Show log button signal hookup */
     g_signal_connect_swapped(log_backup_button, "clicked",
-                    	     G_CALLBACK(show_log_window), widgets);
+                      G_CALLBACK(show_log_window), widgets);
     a++; b++;
 
     /* Spacer label */
@@ -737,16 +731,16 @@ void create_rsync_tab(struct w *widgets)
 
     /* Hseparator */
     make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
-    a++; b++;				
+    a++; b++;
 
     /* Schedule minute (0-59) */
-    widgets->schedule_spin_button[2] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
-									   _("Minute"), 0, 1, a, b, 20, 0, 59);
+    widgets->schedule_spin_button[2] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),
+                                                                            _("Minute"), 0, 1, a, b, 20, 0, 59);
     a++; b++;
 
     /* Every minute (*) */
-    widgets->schedule_check_button[10] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
-                                                                            _("Every minute: "), 0, 1, a, b);
+    widgets->schedule_check_button[10] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table),
+                                                                        _("Every minute: "), 0, 1, a, b);
     a++; b++;
 
     /* Hseparator */
@@ -759,8 +753,8 @@ void create_rsync_tab(struct w *widgets)
     a++; b++;
 
     /* Backup at shutdown [x] */
-    widgets->backup_at_shutdown_check_button = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
-                                                                            _("Backup at shutdown: "), 0, 1, a, b);
+    widgets->backup_at_shutdown_check_button = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table),
+                                                                        _("Backup at shutdown: "), 0, 1, a, b);
     a++; b++;
 
 
@@ -773,7 +767,7 @@ void create_rsync_tab(struct w *widgets)
     // Post command ( Commands to run after the backup. )
 
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     gtk_widget_show_all(widgets->main_window);
 }
