@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,10 +26,7 @@ extern struct w *widgets;
 
 void create_rsync_tab(struct w *widgets);
 
-void directory_cell_edited(GtkCellRendererText *cell,
-			   gchar *path_string,
-			   gchar *new_text,
-			   struct w *widgets);
+void directory_cell_edited(GtkCellRendererText *cell, gchar *path_string, gchar *new_text, struct w *widgets);
 
 void toggle_button_1_clicked(GtkCellRendererToggle *cell_renderer, gchar *path, struct w *widgets);
 
