@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -71,7 +71,6 @@ int main(int argc, char *argv[])
     int i = 0;
     gchar *cmd, *info;
     int fatal_error = 0;
-//    const char *askpass="SSH_ASKPASS";
 
 #ifdef ENABLE_NLS
     bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
@@ -79,41 +78,35 @@ int main(int argc, char *argv[])
     textdomain(GETTEXT_PACKAGE);
 #endif
 
-    gtk_set_locale();
+//    gtk_set_locale();
     gtk_init(&argc, &argv);
 
-    /* Unset SSH_ASKPASS environment variable */
-//    if( ! unsetenv(askpass) )
-//      printf("Unable to unset SSH_ASKPASS environment variable\n");
-
-
     wid* widgets = g_malloc(sizeof(wid));
 
     /* Non root usage */
     if( ! getuid() == 0 )
     {
-	/* For setting a different exit method in the info window */
-	info_window_exit_main = 1;
+        /* For setting a different exit method in the info window */
+        info_window_exit_main = 1;
 
         info = g_strdup_printf("You must be root to run: %s\nThis window will close in 10 seconds.\n", PACKAGE);
         show_info(info);
         g_free(info);
 
-	/* Users can close the info window earlier then the timeout */
-	for(i=0; i<10; i++)
-	{
-    	    while(gtk_events_pending())
+        /* Users can close the info window earlier then the timeout */
+        for(i=0; i<10; i++)
+        {
+            while(gtk_events_pending())
                   gtk_main_iteration();
 
-	    /* Set when close info window is clicked */
-	    if( info_window_exit_main == 2 )
-	      break;
+            /* Set when close info window is clicked */
+            if( info_window_exit_main == 2 )
+                break;
 
-    	    usleep(100000*10);
-    	}
-
-	g_free(widgets);
-	return 0;
+            usleep(100000*10);
+        }
+        g_free(widgets);
+        return 0;
     }
 
 
@@ -121,23 +114,23 @@ int main(int argc, char *argv[])
     global_home_dir = g_get_home_dir();
     if( global_home_dir == NULL )
     {
-	printf("Cant get your home directory.\nUse: \"su - UserName\" to set your environment.\n");
-	g_free(widgets);
-	return 0;
+        printf("Cant get your home directory.\nUse: \"su - UserName\" to set your environment.\n");
+        g_free(widgets);
+        return 0;
     }
 
     /* Settings directories based on mode */
     if( admin_mode )
     {
-	global_settings_dir   = g_strdup_printf("%s/gadmin-rsync/settings", SYSCONFDIR);
-	global_scripts_dir    = g_strdup_printf("%s/gadmin-rsync/scripts", SYSCONFDIR);
-	global_script_log_dir = g_strdup_printf("%s/log/gadmin-rsync", LOCALSTATEDIR);
+        global_settings_dir   = g_strdup_printf("%s/gadmin-rsync/settings", SYSCONFDIR);
+        global_scripts_dir    = g_strdup_printf("%s/gadmin-rsync/scripts", SYSCONFDIR);
+        global_script_log_dir = g_strdup_printf("%s/log/gadmin-rsync", LOCALSTATEDIR);
     }
     else
     {
-	global_settings_dir   = g_strdup_printf("%s/.gadmin-rsync/settings", global_home_dir);
-	global_scripts_dir    = g_strdup_printf("%s/.gadmin-rsync/scripts", global_home_dir);
-	global_script_log_dir = g_strdup_printf("%s/.gadmin-rsync/logs", global_home_dir);
+        global_settings_dir   = g_strdup_printf("%s/.gadmin-rsync/settings", global_home_dir);
+        global_scripts_dir    = g_strdup_printf("%s/.gadmin-rsync/scripts", global_home_dir);
+        global_script_log_dir = g_strdup_printf("%s/.gadmin-rsync/logs", global_home_dir);
     }
     /* We want keys stored in a directory under users homes */
     global_key_path = g_strdup_printf("%s/.gadmin-rsync/keys", global_home_dir);
@@ -147,7 +140,7 @@ int main(int argc, char *argv[])
     cmd = g_strdup_printf("mkdir -p %s %s", global_settings_dir, global_key_path);
     if( ! run_command(cmd) )
     {
-	fatal_error = 1;
+        fatal_error = 1;
 
         info = g_strdup_printf("Error: Can not create directory:\n%s\n", global_settings_dir);
         show_info(info);
@@ -159,7 +152,7 @@ int main(int argc, char *argv[])
     cmd = g_strdup_printf("mkdir -p %s", global_scripts_dir);
     if( ! run_command(cmd) )
     {
-	fatal_error = 1;
+        fatal_error = 1;
 
         info = g_strdup_printf("Error: Can not create directory:\n%s\n", global_scripts_dir);
         show_info(info);
@@ -171,7 +164,7 @@ int main(int argc, char *argv[])
     cmd = g_strdup_printf("mkdir -p %s", global_script_log_dir);
     if( ! run_command(cmd) )
     {
-	fatal_error = 1;
+        fatal_error = 1;
 
         info = g_strdup_printf("Error: Can not create directory:\n%s\n", global_script_log_dir);
         show_info(info);
@@ -187,27 +180,26 @@ int main(int argc, char *argv[])
 
     if( ! fatal_error )
     {
-	/* Create the tabs */
-	create_rsync_tab(widgets);
-	create_progress_tab(widgets);
-	create_disc_tab(widgets);
+        /* Create the tabs */
+        create_rsync_tab(widgets);
+        create_progress_tab(widgets);
+        create_disc_tab(widgets);
 
-	/* Populate the rsync client tab */
-	populate_rsync_tab(widgets);
+        /* Populate the rsync client tab */
+        populate_rsync_tab(widgets);
 
-	/* Populate the disc tab */
-	populate_disc_tab(widgets);
+        /* Populate the disc tab */
+        populate_disc_tab(widgets);
 
-	/* Get the selected backup name from the backup selection combo */
-	global_backup_name = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widgets->rsync_set_combo[0]));
+        /* Get the selected backup name from the backup selection combo */
+        global_backup_name = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widgets->rsync_set_combo[0]));
     }
 
-    /* Window close button (x) */   
-    g_signal_connect(GTK_OBJECT(widgets->main_window), "destroy",
-	             GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+    /* Window close button (x) */
+    g_signal_connect(GTK_WIDGET(widgets->main_window), "destroy",
+                                  G_CALLBACK(gtk_main_quit), NULL);
 
-
-    gtk_timeout_add(1000, (GtkFunction) status_update, widgets);
+    g_timeout_add(1000, (GSourceFunc) status_update, widgets);
 
     gtk_main();
 
@@ -218,5 +210,5 @@ int main(int argc, char *argv[])
     g_free(global_key_path);
     g_free(global_backup_name);
 
-    return 0;    
+    return 0;
 }
