@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include "handle_ssh.h"
 
 
-
 char ** create_gen_key_cmd(char *type, char *bits, char *keypath)
 {
     /* Setup argv for generating public and private certificates.
@@ -109,92 +108,96 @@ int run_ssh_cmd(char *new_argv[], char *password)
     const char *slave_pty_name;
     const char *askpass = "SSH_ASKPASS";
     const char *display = "DISPLAY";
+    /* Avoid unused warning */
+    if( slavepty )
+    {
+    }
 
     masterpty = posix_openpt(O_RDWR|O_NOCTTY);
     if( masterpty == -1 )
     {
-	perror("Can not open a pseudo-terminal master");
-	return 0;
+        perror("Can not open a pseudo-terminal master");
+        return 0;
     }
 
     if( grantpt(masterpty) !=0 )
     {
-	perror("Can not change permission of the pseudo terminal");
-	return 0;
+        perror("Can not change permission of the pseudo terminal");
+        return 0;
     }
     if( unlockpt(masterpty) !=0 )
     {
-	perror("Can not unlock pseudo terminal");
-	return 0;
+        perror("Can not unlock pseudo terminal");
+        return 0;
     }
 
     childpid = fork();
     if( childpid == 0 )
     {
-	/* This is the child process. */
+        /* This is the child process. */
 
-	/* Create a new session. */
-	setsid();
+        /* Create a new session. */
+        setsid();
 
-	/* Get the name of the slave pty */	
-	slave_pty_name = (const char *) ptsname(masterpty);
+        /* Get the name of the slave pty */
+        slave_pty_name = (const char *) ptsname(masterpty);
 
-	/* Open the slave pty */
-	slavepty = open(slave_pty_name, O_RDWR);
-	close(masterpty);
-	
-	/* Show command to run. The password is not shown. */
-	for(i=0; new_argv[i]!=NULL; i++)
-	   fprintf(stderr, "%s ", new_argv[i]);
-	fprintf(stderr, "\n");
+        /* Open the slave pty */
+        slavepty = open(slave_pty_name, O_RDWR);
+        close(masterpty);
 
-	/* Unset SSH_ASKPASS and DISPLAY to disable ssh-askpass popup. */
-	if( unsetenv(askpass) == -1 )
-          fprintf(stderr, "Unable to unset SSH_ASKPASS environment variable.\n");
-	if( unsetenv(display) == -1 )
-          fprintf(stderr, "Unable to unset DISPLAY environment variable.\n");
+        /* Show command to run. The password is not shown. */
+        for(i=0; new_argv[i]!=NULL; i++)
+            fprintf(stderr, "%s ", new_argv[i]);
+        fprintf(stderr, "\n");
 
-	/* Run the command */
-	execvp(new_argv[0], new_argv);
+        /* Unset SSH_ASKPASS and DISPLAY to disable ssh-askpass popup. */
+        if( unsetenv(askpass) == -1 )
+            fprintf(stderr, "Unable to unset SSH_ASKPASS environment variable.\n");
+        if( unsetenv(display) == -1 )
+            fprintf(stderr, "Unable to unset DISPLAY environment variable.\n");
 
-	fprintf(stderr, "Could not run command.\n");
+        /* Run the command */
+        execvp(new_argv[0], new_argv);
 
-	exit(errno);
+        fprintf(stderr, "Could not run command.\n");
+
+        exit(errno);
     }
     else
     if( childpid < 0 )
     {
-	fprintf(stderr, "Can not create child process.\n");
-	return 0;
+        fprintf(stderr, "Can not create child process.\n");
+        return 0;
     }
-	
+
     /* We are the parent */
     do
     {
-	if( ! child_exit )
-	{
-	    fd_set readfd;
+        if( ! child_exit )
+        {
+            fd_set readfd;
 
-	    FD_ZERO(&readfd);
-	    FD_SET(masterpty, &readfd);
+            FD_ZERO(&readfd);
+            FD_SET(masterpty, &readfd);
 
-	    retval_select = select(masterpty+1, &readfd, NULL, NULL, NULL);
-	    if( retval_select > 0 )
-	    {
-		if( FD_ISSET(masterpty, &readfd) )
-		{
-		    if( ! handle_output(masterpty, password) )
-		    {
-			/* Process error. Close the master control pty for the process. */
-			close(masterpty);
-			break;
-		    }
-		}
-	    }
-	    wait_pid = waitpid(childpid, &child_status, WNOHANG);
-	}
-	else
-	  wait_pid = waitpid(childpid, &child_status, 0);
+            retval_select = select(masterpty+1, &readfd, NULL, NULL, NULL);
+            if( retval_select > 0 )
+            {
+                if( FD_ISSET(masterpty, &readfd) )
+                {
+                    if( ! handle_output(masterpty, password) )
+                    {
+                        /* Process error. Close the master control pty for the process. */
+                        close(masterpty);
+                        break;
+                    }
+                }
+            }
+            wait_pid = waitpid(childpid, &child_status, WNOHANG);
+        }
+        else
+            wait_pid = waitpid(childpid, &child_status, 0);
 
     } while( wait_pid == 0 || (! WIFEXITED(child_status) && ! WIFSIGNALED(child_status)) );
 
@@ -217,22 +220,24 @@ int write_string(int fd, char *string)
     ssize_t bytes_written = 0;
 
     if( ! strcmp(string, "\n") )
-	bytes_written =  write(fd, "\n", 1);
+        bytes_written =  write(fd, "\n", 1);
     else
     {
         bytes_written = write(fd, string, strlen(string));
-        write(fd, "\n", 1);
+        if( ! write(fd, "\n", 1) )
+        {
+        }
     }
 
     if( bytes_written == -1 )
     {
-	retval = 0;
+        retval = 0;
         fprintf(stderr, "Error: No bytes written.\n");
     }
     else
     {
-	retval = 1;
-        fprintf(stderr, "Bytes written: %d\n", bytes_written);
+        retval = 1;
+        fprintf(stderr, "Bytes written: %zd\n", bytes_written);
     }
 
     return retval;
@@ -250,77 +255,75 @@ int handle_output(int fd, char *password)
     char output[128]="";
     char line[128]="";
     int  i=0, x=0, num_pass_tries=0, bytes_read=0;
-    
+
     bytes_read = read(fd, output, sizeof(output));
 
     /* Nothing to read. Return OK. */
     if( bytes_read == -1 )
       return 1;
 
-
-    for(i=0; i<=128; i++)
+    for(i=0; i<128; i++) /* Bugfix: 2014-11-06: Buffer overflow of 1 char */
     {
-	line[x] = output[i];
-	x++;
-	
-	if( output[i]!='\0' && output[i]!='\r' && output[i]!='\n' )
-	    continue;
+        line[x] = output[i];
+        x++;
 
-	if( strlen(line) < 7 )
-	  continue;
+        if( output[i]!='\0' && output[i]!='\r' && output[i]!='\n' )
+            continue;
 
-	if( strstr(line, key_overwrite_line) )
-	{
-	    fprintf(stderr, "Overwriting old keys.\n");
-	    if( ! write_string(fd, "yes") )
-	    {
-	        retval = 0;
-		break;
-	    }
-	}
+        if( strlen(line) < 7 )
+            continue;
 
-	if( strstr(line, pass_phrase_line) )
-	{
-	    fprintf(stderr, "Writing empty key phrase.\n");
-	    if( ! write_string(fd, "\n") )
-	    {
-	        retval = 0;
-	        break;
-	    }
-	}
+        if( strstr(line, key_overwrite_line) )
+        {
+            fprintf(stderr, "Overwriting old keys.\n");
+            if( ! write_string(fd, "yes") )
+            {
+                retval = 0;
+                break;
+            }
+        }
 
-	if( strstr(line, auth_line) )
-	{
-	    fprintf(stderr, "Allowing authentication to proceed.\n");
-	    if( ! write_string(fd, "yes") )
-	    {
-	        retval = 0;
-	        break;
-	    }
-	}
+        if( strstr(line, pass_phrase_line) )
+        {
+            fprintf(stderr, "Writing empty key phrase.\n");
+            if( ! write_string(fd, "\n") )
+            {
+                retval = 0;
+                break;
+            }
+        }
 
-	if( strstr(line, pass_line) )
-	{
-	    fprintf(stderr, "Supplying password.\n");
-	    if( ! write_string(fd, password) )
-	    {
-	        retval = 0;
-	        break;
-	    }
+        if( strstr(line, auth_line) )
+        {
+            fprintf(stderr, "Allowing authentication to proceed.\n");
+            if( ! write_string(fd, "yes") )
+            {
+                retval = 0;
+                break;
+            }
+        }
 
-// Must be global...
-	    num_pass_tries++;
-	    
-	    if( num_pass_tries > 2 )
-	    {
-		fprintf(stderr, "Error: Wrong password.\n");
-		retval = 0;
-		break;
-	    }
-	}
+        if( strstr(line, pass_line) )
+        {
+            fprintf(stderr, "Supplying password.\n");
+            if( ! write_string(fd, password) )
+            {
+                retval = 0;
+                break;
+            }
 
-	x = 0;
-	line[x]='\0';
+            num_pass_tries++;
+
+            if( num_pass_tries > 2 )
+            {
+                fprintf(stderr, "Error: Wrong password.\n");
+                retval = 0;
+                break;
+            }
+        }
+
+        x = 0;
+        line[x]='\0';
     }
 
     return retval;
