@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,28 +48,25 @@ int setup_keys(gchar *user, gchar *password, gchar *host, gchar *port, gchar *ty
     if( is_empty(user) || is_empty(password) || is_empty(host)
     ||  is_empty(port) || is_empty(type) || is_empty(len) )
     {
-	info = g_strdup_printf(_("Every field must be filled in.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Every field must be filled in.\n"));	
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
-	return retval;    
+        return retval;
     }
 
     if( ! generate_keys(user, host, type, len, widgets) )
     {
-	// Naah... printf("Key already exists or keygen failed.\n");
-
-	return retval;
+        return retval;
     }
     else
     {
         /* Upload key to remote host and install them there */
         if( ! install_remote_key(user, host, port, password, widgets) )
-	{
-	    // Naah...  printf("Key upload failed.\n");
-	    return retval;
-	}
+        {
+            return retval;
+        }
     }
 
     return 1;
@@ -90,12 +87,12 @@ int is_empty(gchar *input)
 gchar * mk_key_name(gchar *user, gchar *host, char type[128])
 {
     gchar *key_name;
-    
+
     if( strstr(type, "priv") )
       key_name = g_strdup_printf("%s.%s.key", user, host);
     else
       key_name = g_strdup_printf("%s.%s.key.pub", user, host);
-    
+
     return key_name;
 }
 
@@ -104,7 +101,7 @@ int key_exists(gchar *key_name)
 {
     int retval = 0;
     gchar *key_path = g_strdup_printf("%s/%s", global_key_path, key_name);
-    
+
     if( file_exists(key_path) )
       retval = 1;
 
@@ -128,55 +125,53 @@ int generate_keys(gchar *user, gchar *host, gchar *key_type, gchar *key_len, str
     key_path_pub  = g_strdup_printf("%s/%s.pub", global_key_path, key_name);
 
     /* If we have both local keys for this site, dont generate new ones */
-/*  New: I think it would be better to just generate new keys instead...  
+/*  New: I think it would be better to just generate new keys instead...
     if( file_exists(key_path_priv) && file_exists(key_path_pub) )
     {
-// Not needed	printf("The local private and public keys exists.\nNot generating new local keys.\n");
-	info = g_strdup_printf(_("Keys for this remote host already exists.\nNew keys where not generated.\n"));
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Keys for this remote host already exists.\nNew keys where not generated.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
-	g_free(key_path_priv);
-	g_free(key_path_pub);
-	g_free(key_name);
+        g_free(key_path_priv);
+        g_free(key_path_pub);
+        g_free(key_name);
 
-	return retval;
+        return 1;
     }
 */
 
     if( file_exists(key_path_priv) )
     {
-	printf("The private key already exists, removing it.\n");
-	unlink(key_path_priv);
+        printf("The private key already exists, removing it.\n");
+        unlink(key_path_priv);
     }
 
     if( file_exists(key_path_pub) )
     {
-	printf("The public key already exists, removing it.\n");
-	unlink(key_path_pub);
+        printf("The public key already exists, removing it.\n");
+        unlink(key_path_pub);
     }
 
     printf("Generating private key: %s\n", key_path_priv);
     printf("Generating public  key: %s\n", key_path_pub);
 
-
     new_argv = create_gen_key_cmd(key_type, key_len, key_path_priv);
 
     if( ! run_ssh_cmd(new_argv, NULL) )
     {
-	info = g_strdup_printf(_("Error: Can not generate keys for this host.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Error: Can not generate keys for this host.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
         printf("Error: Key generation failed.\n");
         retval = 0;
     }
     else
     {
-//        printf("Key generation successful.\n");
-	retval = 1;
+        printf("Key generation successful.\n");
+        retval = 1;
     }
     free(new_argv);
 
@@ -199,47 +194,45 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
 
     key_name_priv = mk_key_name(user, host, "priv");
     key_name_pub  = mk_key_name(user, host, "pub");
-    
+
     key_path_priv = g_strdup_printf("%s/%s", global_key_path, key_name_priv);
     key_path_pub  = g_strdup_printf("%s/%s", global_key_path, key_name_pub);
 
     if( ! file_exists(key_path_priv) )
     {
-	info = g_strdup_printf(_("Error: The local private key does not exist.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Error: The local private key does not exist.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
-	printf("Error: The local private key doesnt exist: %s\n", key_path_priv);
+        printf("Error: The local private key doesnt exist: %s\n", key_path_priv);
 
-	g_free(key_name_priv);
-	g_free(key_name_pub);
-	g_free(key_path_priv);
-	g_free(key_path_pub);
+        g_free(key_name_priv);
+        g_free(key_name_pub);
+        g_free(key_path_priv);
+        g_free(key_path_pub);
 
-	return retval;
+        return retval;
     }
 
     g_free(key_name_priv);
     g_free(key_path_priv);
 
-
     if( ! file_exists(key_path_pub) )
     {
-	info = g_strdup_printf(_("Error: The local public key does not exist.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Error: The local public key does not exist.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
-	printf("Error: The local public key doesnt exist: %s\n", key_path_pub);
+        printf("Error: The local public key doesnt exist: %s\n", key_path_pub);
 
-	g_free(key_name_pub);
-	g_free(key_path_pub);
+        g_free(key_name_pub);
+        g_free(key_path_pub);
 
-	return retval;
+        return retval;
     }
 
-
     /* Make the key install script */
     script_name = g_strdup_printf("gadmin-rsync-ssh.sh");
 
@@ -250,13 +243,13 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
     "fi\n\n",
 
     "cd .ssh || exit 1\n\n",
-	
+
     "if [ ! -f authorized_keys ]; then\n",
     "   touch authorized_keys && chmod 600 authorized_keys\n"
     "fi\n\n"
-		
+
     "cat ../", key_name_pub, " >> authorized_keys\n",
-    
+
     "rm -f ../", key_name_pub, "\n",
     "rm -f ../", script_name, "\n",
     NULL);
@@ -269,21 +262,19 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
 
     if((fp=fopen(script_path, "w+"))==NULL)
     {
-	printf("Error writing install script file here: %s\n", script_path);
+        printf("Error writing install script file here: %s\n", script_path);
 
-	g_free(script);
-	g_free(script_name);
-	g_free(script_path);
-	g_free(key_path_pub);
+        g_free(script);
+        g_free(script_name);
+        g_free(script_path);
+        g_free(key_path_pub);
 
-	return retval;
+        return retval;
     }
     fputs(script, fp);
-    fclose(fp);    
-
+    fclose(fp);
     g_free(script);
 
-
     /* Upload public key and key install script to the remote server */
     gchar *user_host_dir = g_strdup_printf("%s@%s:~", user, host);
 
@@ -291,57 +282,53 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
 
     if( ! run_ssh_cmd(new_argv, password) )
     {
-	printf("Error uploading key.\n");
-	g_free(script_path);
-	g_free(key_path_pub);
-	g_free(user_host_dir);
-	g_free(script_name);
-	free(new_argv);
+        printf("Error uploading key.\n");
+        g_free(script_path);
+        g_free(key_path_pub);
+        g_free(user_host_dir);
+        g_free(script_name);
+        free(new_argv);
 
-	return retval;
+        return retval;
     }
-
     free(new_argv);
     g_free(user_host_dir);
 
-
     /* Create the key install command */
     gchar *ssh_cmd = g_strdup_printf("chmod 755 ~/%s && sh ~/%s && rm -f ~/%s", script_name, script_name, script_name);
-    
+
     new_argv = create_ssh_cmd(user, host, port, ssh_cmd);
 
     if( ! run_ssh_cmd(new_argv, password) )
     {
-	info = g_strdup_printf(_("Error: Could not install the public key on the remote host.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        info = g_strdup_printf(_("Error: Could not install the public key on the remote host.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
         printf("Error installing key on the remote host.\n");
-        
-	g_free(script_path);
-	g_free(key_path_pub);
-	g_free(script_name);
-	g_free(ssh_cmd);
-	free(new_argv);
 
-	return retval;
+        g_free(script_path);
+        g_free(key_path_pub);
+        g_free(script_name);
+        g_free(ssh_cmd);
+        free(new_argv);
+
+        return retval;
     }
     else
     {
-	/* This info is good. Will be shown in the progress bar later */
-	info = g_strdup_printf(_("Public key installation on remote host successful.\n"));	
-	show_info(info);
-	if( info!=NULL )
-	  g_free(info);
+        /* This info is good. Will be shown in the progress bar later */
+        info = g_strdup_printf(_("Public key installation on remote host successful.\n"));
+        show_info(info);
+        if( info!=NULL )
+            g_free(info);
 
         printf("Key installation successful.\n");
 
-	retval = 1;
+        retval = 1;
     }
-
     free(new_argv);
-
     g_free(ssh_cmd);
     g_free(script_name);
 
@@ -351,6 +338,5 @@ int install_remote_key(gchar *user, gchar *host, gchar *port, gchar *password, s
 
     g_free(key_path_pub);
 
-
     return retval;
 }
