@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,28 +36,4 @@ void restore_local_src_filesel_ok(struct w *widgets);
 void show_restore_local_dst_filesel(struct w *widgets);
 void restore_local_dst_filesel_ok(struct w *widgets);
 
-
-
-// Not used...
-
-//void restore_button_clicked(struct w *widgets);
-
-/*
-void show_server_menu(char type[128], struct w *widgets);
-
-void show_src_filesel(struct w *widgets);
-void show_dst_filesel(struct w *widgets);
-
-void src_filesel_ok(struct w *widgets);
-void dst_filesel_ok(struct w *widgets);
-
-void src_filesel_cancel(struct w *widgets);
-void dst_filesel_cancel(struct w *widgets);
-
-void scroll_to_last_row(GtkTreeView *treeview);
-
-void backup_local_checkbutton_toggled(GtkButton *button, struct w *widgets);
-void backup_local_remote_checkbutton_toggled(GtkButton *button, struct w *widgets);
-void backup_remote_local_checkbutton_toggled(GtkButton *button, struct w *widgets);
-*/
 #endif
