@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,36 +47,36 @@ void delete_log(struct w *widgets)
     {
         printf("clear_log: log path too short\n");
         if( log_path!=NULL )
-          g_free(log_path);
-	return;
+            g_free(log_path);
+        return;
     }
     if((fp=fopen(log_path, "w+"))==NULL)
     {
         if( log_path!=NULL )
-          g_free(log_path);
-	return;
+            g_free(log_path);
+        return;
     }
     fclose(fp);
 
     if( log_path!=NULL )
-      g_free(log_path);
+        g_free(log_path);
 
     log_path = mk_extended_log_path(global_backup_name);
     if( log_path == NULL || strlen(log_path) < 10 )
     {
-       printf("clear_log: extended log path too short\n");
-       return;
+         printf("clear_log: extended log path too short\n");
+         return;
     }
     if((fp=fopen(log_path, "w+"))==NULL)
     {
         if( log_path!=NULL )
-          g_free(log_path);
-	return;
+            g_free(log_path);
+        return;
     }
     fclose(fp);
 
     if( log_path!=NULL )
-      g_free(log_path);
+        g_free(log_path);
 
     populate_log(widgets);
 }
@@ -95,12 +95,12 @@ void populate_log(struct w *widgets)
     log_path = mk_log_path(global_backup_name);
     if( log_path == NULL || strlen(log_path) < 10 )
     {
-	info = g_strdup_printf("Can not read the selected backups logfile. Filename too short.\n");
-	show_info(info);
-	g_free(info);
+        info = g_strdup_printf("Can not read the selected backups logfile. Filename too short.\n");
+        show_info(info);
+        g_free(info);
 
-	if( log_path!=NULL )       
-          g_free(log_path);
+        if( log_path!=NULL )
+            g_free(log_path);
 
         /* Destroy the backup log window and return */
         gtk_widget_destroy(widgets->log_window);
@@ -116,12 +116,12 @@ void populate_log(struct w *widgets)
     if((fp=fopen(log_path, "r"))==NULL)
     {
         info = g_strdup_printf("Can not read the selected backups logfile.\nThe backup needs to run first so a log is created.\n");
-	show_info(info);
-	g_free(info);
+        show_info(info);
+        g_free(info);
+
+        if( log_path!=NULL )
+            g_free(log_path);
 
-	if( log_path!=NULL )       
-          g_free(log_path);
-        
         /* Destroy the backup log window and return */
         gtk_widget_destroy(widgets->log_window);
         return;
@@ -129,117 +129,117 @@ void populate_log(struct w *widgets)
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
     rewind(fp);
-                                            
+
     line = allocate(file_size+1);
     val  = allocate(file_size+1);
-                                                        
+
     if( file_size > 1 )
     while(fgets(line, file_size, fp)!=NULL)
-    {                                 
-	if( strlen(line) < 10  )
-	  continue;
+    {
+        if( strlen(line) < 10  )
+            continue;
 
-	gtk_list_store_append(GTK_LIST_STORE(widgets->log_store), &iter);
+        gtk_list_store_append(GTK_LIST_STORE(widgets->log_store), &iter);
 
-	/* Insert start date and time */
-	sscanf(line, "%s", val);
-	for(i=0; val[i]!='\0'; i++)
-	{
-	    /* Change underscore to a space */
-	    if( val[i]=='_' )
-	      val[i]=' ';
-	}
-	utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
-	if( utf8!=NULL )
-	{
-	    gtk_list_store_set(widgets->log_store, &iter, 0, utf8, -1);
-	    g_free(utf8);
-	}
+        /* Insert start date and time */
+        sscanf(line, "%s", val);
+        for(i=0; val[i]!='\0'; i++)
+        {
+            /* Change underscore to a space */
+            if( val[i]=='_' )
+                val[i]=' ';
+        }
+        utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
+        if( utf8!=NULL )
+        {
+            gtk_list_store_set(widgets->log_store, &iter, 0, utf8, -1);
+            g_free(utf8);
+        }
 
-	/* Insert finish date and time */
-	sscanf(line, "%*s %s", val);
-	for(i=0; val[i]!='\0'; i++)
-	{
-	    /* Change underscore to a space */
-	    if( val[i]=='_' )
-	      val[i]=' ';
-	}
-	utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
-	if( utf8!=NULL )
-	{
-	    gtk_list_store_set(widgets->log_store, &iter, 1, utf8, -1);
-	    g_free(utf8);
-	}
+        /* Insert finish date and time */
+        sscanf(line, "%*s %s", val);
+        for(i=0; val[i]!='\0'; i++)
+        {
+            /* Change underscore to a space */
+            if( val[i]=='_' )
+                val[i]=' ';
+        }
+        utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
+        if( utf8!=NULL )
+        {
+            gtk_list_store_set(widgets->log_store, &iter, 1, utf8, -1);
+            g_free(utf8);
+        }
 
-	/* Insert success / failure state */
-	sscanf(line, "%*s %*s %*s %s", val);
-	if( strstr(line, "success") )
-	  utf8 = g_locale_to_utf8("Success", -1, NULL, NULL, NULL);
-	else
-	  utf8 = g_locale_to_utf8("Failure", -1, NULL, NULL, NULL);
-	
-	if( utf8!=NULL )
-	{
-	    gtk_list_store_set(widgets->log_store, &iter, 2, utf8, -1);
-	    g_free(utf8);
-	}
+        /* Insert success / failure state */
+        sscanf(line, "%*s %*s %*s %s", val);
+        if( strstr(line, "success") )
+            utf8 = g_locale_to_utf8("Success", -1, NULL, NULL, NULL);
+        else
+            utf8 = g_locale_to_utf8("Failure", -1, NULL, NULL, NULL);
 
-	/* Insert source */
-	for(i=0; line[i]!='\0'; i++)
-	{
-	    if( line[i]=='[' )
-	      break;
-	}
-	begin = i+1;
+        if( utf8!=NULL )
+        {
+            gtk_list_store_set(widgets->log_store, &iter, 2, utf8, -1);
+            g_free(utf8);
+        }
 
-	for(i=i; line[i]!='\0'; i++)
-	{
-	    if( line[i]==']' )
-	      break;
-	}
-	i++;
+        /* Insert source */
+        for(i=0; line[i]!='\0'; i++)
+        {
+            if( line[i]=='[' )
+                break;
+        }
+        begin = i+1;
 
-	snprintf(val, i-begin, "%s", &line[begin]);
-	utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
-	if( utf8!=NULL )
-	{
-	    gtk_list_store_set(widgets->log_store, &iter, 3, utf8, -1);
-	    g_free(utf8);
-	}
+        for(i=i; line[i]!='\0'; i++)
+        {
+            if( line[i]==']' )
+                break;
+        }
+        i++;
 
-	/* Insert destination */
-	for(i=i; line[i]!='\0'; i++)
-	{
-	    if( line[i]=='[' )
-	    {
-		begin = i;
-		break;
-	    }
-	}
-	begin = i+1;
+        snprintf(val, i-begin, "%s", &line[begin]);
+        utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
+        if( utf8!=NULL )
+        {
+            gtk_list_store_set(widgets->log_store, &iter, 3, utf8, -1);
+            g_free(utf8);
+        }
 
-	for(i=i; line[i]!='\0'; i++)
-	{
-	    if( line[i]==']' )
-	    {
-		line[i]='\0';
-	        break;
-	    }
-	}
-	i++;
-	
-	snprintf(val, i-begin, "%s", &line[begin]);
-	utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
-	if( utf8!=NULL )
-	{
-	    gtk_list_store_set(widgets->log_store, &iter, 4, utf8, -1);
-	    g_free(utf8);
-	}
+        /* Insert destination */
+        for(i=i; line[i]!='\0'; i++)
+        {
+            if( line[i]=='[' )
+            {
+                begin = i;
+                break;
+            }
+        }
+        begin = i+1;
+
+        for(i=i; line[i]!='\0'; i++)
+        {
+            if( line[i]==']' )
+            {
+                line[i]='\0';
+                break;
+            }
+        }
+        i++;
+
+        snprintf(val, i-begin, "%s", &line[begin]);
+        utf8 = g_locale_to_utf8(val, strlen(val), NULL, NULL, NULL);
+        if( utf8!=NULL )
+        {
+            gtk_list_store_set(widgets->log_store, &iter, 4, utf8, -1);
+            g_free(utf8);
+        }
     }
     fclose(fp);
 
     if( log_path!=NULL )
-    g_free(log_path);
+        g_free(log_path);
 
     free(line);
     free(val);
@@ -256,7 +256,7 @@ void show_log_window(struct w *widgets)
     GtkWidget *hbuttonbox;
     GtkTooltips *tooltips;
     gchar *info;
-    int colnr = 0;    
+    int colnr = 0;
 
     tooltips = gtk_tooltips_new();
 
@@ -264,7 +264,7 @@ void show_log_window(struct w *widgets)
     widgets->log_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_widget_set_size_request(widgets->log_window, 630, 350);
     gtk_window_set_position(GTK_WINDOW(widgets->log_window), GTK_WIN_POS_CENTER);
-  
+
     /* Set window information */
     info = g_strdup_printf(_("GAdmin-Rsync %s \t %s"), VERSION, global_backup_name);
     gtk_window_set_title(GTK_WINDOW(widgets->log_window), info);
@@ -277,16 +277,15 @@ void show_log_window(struct w *widgets)
     scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(vbox), scrolled_window, TRUE, TRUE, 0);
 
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(scrolled_window, -1, 100);
 
 
     /* 7 columns (Date, State, Src, Dst) */
     widgets->log_store = gtk_list_store_new(5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
-    
+
     widgets->log_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->log_treeview), GTK_TREE_MODEL(widgets->log_store));
 
@@ -320,7 +319,7 @@ void show_log_window(struct w *widgets)
     hbuttonbox = gtk_hbutton_box_new();
     gtk_box_pack_start(GTK_BOX(vbox), hbuttonbox, FALSE, FALSE, 0);
     gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox), GTK_BUTTONBOX_SPREAD);
-            
+
 
     /* Fixme: Use custom text "Clear log". The clear log button */
     GtkWidget *delete_log_button = gtk_button_new_from_stock(GTK_STOCK_DELETE);
@@ -344,7 +343,7 @@ void show_log_window(struct w *widgets)
     GtkWidget *label2 = gtk_label_new_with_mnemonic(_("Show extended log"));
     gtk_box_pack_start(GTK_BOX(hbox2), label2, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label2), GTK_JUSTIFY_LEFT);
-            
+
     /* Show extended log button signal */
     g_signal_connect_swapped(extended_log_button, "clicked",
                            G_CALLBACK(show_extended_log_window), widgets);
@@ -358,8 +357,8 @@ void show_log_window(struct w *widgets)
     g_signal_connect_swapped((gpointer) close_log_button, "clicked",
               G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(widgets->log_window));
 
-    g_signal_connect(GTK_WINDOW(widgets->log_window), "delete_event", 
-		        G_CALLBACK(gtk_widget_destroy), NULL);
+    g_signal_connect(GTK_WINDOW(widgets->log_window), "delete_event",
+                                 G_CALLBACK(gtk_widget_destroy), NULL);
 
     gtk_widget_show_all(widgets->log_window);
 
@@ -378,7 +377,7 @@ void show_extended_log_window(struct w *widgets)
     GtkWidget *hbuttonbox;
     GtkTooltips *tooltips;
     gchar *info;
-    int colnr = 0;    
+    int colnr = 0;
 
     tooltips = gtk_tooltips_new();
 
@@ -386,7 +385,7 @@ void show_extended_log_window(struct w *widgets)
     widgets->extended_log_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_widget_set_size_request(widgets->extended_log_window, 630, 350);
     gtk_window_set_position(GTK_WINDOW(widgets->extended_log_window), GTK_WIN_POS_CENTER);
-  
+
     /* Set window information */
     info = g_strdup_printf(_("GAdmin-Rsync %s \t %s"), VERSION, global_backup_name);
     gtk_window_set_title(GTK_WINDOW(widgets->extended_log_window), info);
@@ -399,14 +398,13 @@ void show_extended_log_window(struct w *widgets)
     scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(vbox), scrolled_window, TRUE, TRUE, 0);
 
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(scrolled_window, -1, 100);
 
     widgets->extended_log_store = gtk_list_store_new(1, G_TYPE_STRING);
-    
+
     widgets->extended_log_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->extended_log_treeview), GTK_TREE_MODEL(widgets->extended_log_store));
 
@@ -433,8 +431,8 @@ void show_extended_log_window(struct w *widgets)
     g_signal_connect_swapped((gpointer) close_log_button, "clicked",
               G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(widgets->extended_log_window));
 
-    g_signal_connect(GTK_WINDOW(widgets->extended_log_window), "delete_event", 
-		        G_CALLBACK(gtk_widget_destroy), NULL);
+    g_signal_connect(GTK_WINDOW(widgets->extended_log_window), "delete_event",
+                                          G_CALLBACK(gtk_widget_destroy), NULL);
 
     gtk_widget_show_all(widgets->extended_log_window);
 
@@ -456,10 +454,9 @@ void populate_extended_log(struct w *widgets)
     extended_log_path = mk_extended_log_path(global_backup_name);
     if( extended_log_path == NULL || strlen(extended_log_path) < 10 )
     {
-	info = g_strdup_printf("Can not read the selected backups extended logfile. Filename too short.\n");
-	show_info(info);
-	g_free(info);
-       
+        info = g_strdup_printf("Can not read the selected backups extended logfile. Filename too short.\n");
+        show_info(info);
+        g_free(info);
         g_free(extended_log_path);
 
         /* Destroy the backup log window and return */
@@ -475,11 +472,10 @@ void populate_extended_log(struct w *widgets)
     if((fp=fopen(extended_log_path, "r"))==NULL)
     {
         info = g_strdup_printf("Can not read the selected backups extended logfile.\n");
-	show_info(info);
-	g_free(info);
-
+        show_info(info);
+        g_free(info);
         g_free(extended_log_path);
-        
+
         /* Destroy the backup log window and return */
         gtk_widget_destroy(widgets->extended_log_window);
         return;
@@ -487,33 +483,32 @@ void populate_extended_log(struct w *widgets)
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
     rewind(fp);
-                                            
+
     line = allocate(file_size+1);
-                                                        
+
     if( file_size > 1 )
     while(fgets(line, file_size, fp)!=NULL)
-    {                                 
-	if( strlen(line) < 10 || strlen(line) > 20000 )
-	  continue;
+    {
+        if( strlen(line) < 10 || strlen(line) > 20000 )
+            continue;
 
-	for(i=0; line[i]!='\0'; i++)
-	if( line[i]=='\n' )
-	{    
-	    line[i]='\0';
-	    break;
-	}
+        for(i=0; line[i]!='\0'; i++)
+        if( line[i]=='\n' )
+        {
+            line[i]='\0';
+            break;
+        }
 
-	gtk_list_store_append(GTK_LIST_STORE(widgets->extended_log_store), &iter);
+        gtk_list_store_append(GTK_LIST_STORE(widgets->extended_log_store), &iter);
 
-	utf8 = g_locale_to_utf8(line, strlen(line), NULL, NULL, NULL);
-	if( utf8!=NULL )
-	{
-	    gtk_list_store_set(widgets->extended_log_store, &iter, 0, utf8, -1);
-	    g_free(utf8);
-	}
+        utf8 = g_locale_to_utf8(line, strlen(line), NULL, NULL, NULL);
+        if( utf8!=NULL )
+        {
+            gtk_list_store_set(widgets->extended_log_store, &iter, 0, utf8, -1);
+            g_free(utf8);
+        }
     }
     fclose(fp);
     g_free(extended_log_path);
-
     free(line);
 }
