@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007-2011 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007 - 2014 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ char * get_process_pid(char process[1024])
 
     pid = allocate(1024);
     strcpy(pid, "0");
-    
+
     sub_proc_path = allocate(1024);
 
     num = scandir(PROC_PATH, &namelist, 0, alphasort);
@@ -64,30 +64,30 @@ char * get_process_pid(char process[1024])
         /* List all directories in PROC_PATH */
         for(x=0; x<num; x++)
         {
-	    /* Now list PROC_PATH/24207/cmdline */
-	    snprintf(sub_proc_path, 1000, "%s/%s/cmdline", PROC_PATH, namelist[x]->d_name);
+            /* Now list PROC_PATH/24207/cmdline */
+            snprintf(sub_proc_path, 1000, "%s/%s/cmdline", PROC_PATH, namelist[x]->d_name);
 
-	    if((fp=fopen(sub_proc_path, "r"))==NULL)
-	    {
-        	free(namelist[x]);
-	        continue;
-	    }
-	    line = allocate(file_size+1);
-	    
-	    if( file_size > 1 )
-	    while(fgets(line, file_size, fp)!=NULL)
-	    {
-		/* If the following strings are detected in this file its running */
-		if( strcmp(line, process) == 0 )
-		{
-		    snprintf(pid, 1000, "%s", namelist[x]->d_name);
-		    break;
-		}
-	    }
-	    fclose(fp);
-	    free(line);
+            if((fp=fopen(sub_proc_path, "r"))==NULL)
+            {
+                free(namelist[x]);
+                continue;
+            }
+            line = allocate(file_size+1);
+
+            if( file_size > 1 )
+            while(fgets(line, file_size, fp)!=NULL)
+            {
+                /* If the following strings are detected in this file its running */
+                if( strcmp(line, process) == 0 )
+                {
+                    snprintf(pid, 1000, "%s", namelist[x]->d_name);
+                    break;
+                }
+            }
+            fclose(fp);
+            free(line);
             free(namelist[x]);
-	}
+        }
     }
     free(namelist);
     free(sub_proc_path);
@@ -100,7 +100,6 @@ int status_update(struct w *widgets)
 {
     char *pid;
     gchar *info1, *utf8=NULL;
-/*    gchar *info2; for server status */
     GdkColor color;
 
     /* Check if rsync backup is running */
@@ -108,7 +107,7 @@ int status_update(struct w *widgets)
     if( strcmp(pid, "0") == 0 )
     {
         client_active = 0;
-	info1 = g_strdup_printf(_("Status: Backup is not running."));
+        info1 = g_strdup_printf(_("Status: Backup is not running."));
     }
     else
     {
@@ -117,42 +116,25 @@ int status_update(struct w *widgets)
     }
     free(pid);
 
-    /* Check if rsync daemon is running */
-/*
-    pid = get_process_pid("rsync --daemon");
-    if( strcmp(pid, "0") == 0 )
-    {
-        server_active = 0;
-        info2 = g_strdup_printf(_("%s Server deactivated"), info1);
-    }
-    else
-    {
-        server_active = 1;
-        info2 = g_strdup_printf(_("%s Server activated"), info1);
-    }
-    free(pid);
-*/
-
     /* Server status: utf8 = g_locale_to_utf8(info, strlen(info2), NULL, NULL, NULL); */
     utf8 = g_locale_to_utf8(info1, strlen(info1), NULL, NULL, NULL);
     gtk_label_set_text(GTK_LABEL(widgets->status_label), utf8);
     if( utf8!=NULL )
-      g_free(utf8);
+        g_free(utf8);
 
     g_free(info1);
-/* Server status: g_free(info2); */
 
     if( client_active )
     {
-	/* Set status color */
-	gdk_color_parse("dark green", &color);
-	gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);    
+        /* Set status color */
+        gdk_color_parse("dark green", &color);
+        gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);    
     }
     else
     {
-	/* Set status color */
-	gdk_color_parse("red", &color);
-	gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);    
+        /* Set status color */
+        gdk_color_parse("red", &color);
+        gtk_widget_modify_fg(widgets->status_label, GTK_STATE_NORMAL, &color);    
     }
 
     return (TRUE);
